@@ -1,12 +1,12 @@
 package Linux::Statm::Tiny;
-$Linux::Statm::Tiny::VERSION = '0.0100';
+$Linux::Statm::Tiny::VERSION = '0.0200';
 use Moo;
 
 use Fcntl qw/ O_RDONLY /;
 use Types::Standard qw/ ArrayRef Int /;
 
 {
-    $Linux::Statm::Tiny::VERSION = '0.0100'
+    $Linux::Statm::Tiny::VERSION = '0.0200'
 }
 
 =head1 NAME
@@ -81,10 +81,14 @@ sub _build_statm {
 
 =head2 C<size>
 
+=head2 c<vss>
+
 Total program size, in pages.
 
 =head2 C<resident>
 
+=head2 C<rss>
+
 Resident set size (RSS), in pages.
 
 =head2 C<share>
@@ -128,6 +132,14 @@ foreach my $attr (keys %stats) {
         );
     }
 
+sub vss {
+    shift->size(@_);
+    }
+
+sub rss {
+    shift->resident(@_);
+    }
+
 =for readme continue
 
 =head1 SEE ALSO
